=== modified file 'bzrlib/bugtracker.py'
--- bzrlib/bugtracker.py	2009-03-12 07:00:53 +0000
+++ bzrlib/bugtracker.py	2009-03-12 07:06:18 +0000
@@ -284,7 +284,10 @@
 tracker_registry.register('generic', GenericBugTracker())
 
 
+FIXED = 'fixed'
+
+
 def encode_fixes_bug_urls(bug_urls):
     """Return the 'bugs' property value for a revision that fixes 'bug_urls'.
     """
-    return '\n'.join(('%s fixed' % url) for url in bug_urls)
+    return '\n'.join(('%s %s' % (url, FIXED)) for url in bug_urls)

=== modified file 'bzrlib/tests/test_bugtracker.py'
--- bzrlib/tests/test_bugtracker.py	2008-04-03 05:02:07 +0000
+++ bzrlib/tests/test_bugtracker.py	2009-03-12 07:06:18 +0000
@@ -16,7 +16,7 @@
 
 
 from bzrlib import bugtracker, errors, urlutils
-from bzrlib.tests import TestCaseWithMemoryTransport
+from bzrlib.tests import TestCase, TestCaseWithMemoryTransport
 
 
 class TestGetBugURL(TestCaseWithMemoryTransport):
@@ -210,3 +210,22 @@
         """
         self.assertRaises(
             errors.MalformedBugIdentifier, self.tracker.get_bug_url, 'bad')
+
+
+class TestPropertyEncoding(TestCase):
+    """Tests for how the bug URLs are encoded as revision properties."""
+
+    def test_encoding_one(self):
+        self.assertEqual(
+            'http://example.com/bugs/1 fixed',
+            bugtracker.encode_fixes_bug_urls(['http://example.com/bugs/1']))
+
+    def test_encoding_zero(self):
+        self.assertEqual('', bugtracker.encode_fixes_bug_urls([]))
+
+    def test_encoding_two(self):
+        self.assertEqual(
+            'http://example.com/bugs/1 fixed\n'
+            'http://example.com/bugs/2 fixed',
+            bugtracker.encode_fixes_bug_urls(
+                ['http://example.com/bugs/1', 'http://example.com/bugs/2']))

